@@ -118,7 +118,7 @@ class LinuxDevice(object):
     '''
     A base class for common linux devices.
     '''
-    release = '1.1.20'
+    release = '1.1.22'
 
     LOG_EMERG = 0   # not used
     LOG_ALERT = 1   # not used
@@ -207,8 +207,8 @@ class LinuxDevice(object):
             #self.del__configure_interface()
             self._preconfig()
 
-        self.log("welcome to netdevice %s, %s device %s.\n" %(self.release,
-            self["type"], self["hostname"]))
+        self.log("welcome to %s device: %s, netdevice rev: %s.\n" %(self["type"],
+            self["hostname"], self.release))
         #if self["type"] == 'Linux':
         #    tmp = copy.deepcopy(self.attributes)
         #    tmp["password"] = "*******"
