@@ -267,24 +267,30 @@ class OvsHost(linux.LinuxDevice):
         for p in vm.get("port", []):
             device = self._util_dictionary_parse(p["-device"].split(","))
             if "vhost-user" in p["-netdev"]:
-                # type: vhostuserclient
                 chardev = self._util_dictionary_parse(p["-chardev"].split(","))
-                port_name = "to_%s_%s" %(vm["-name"], os.path.basename(chardev["path"]))
-                ovs_port = {"name": port_name,
-                        "type": "dpdkvhostuserclient",
-                        "options:vhost-server-path": chardev["path"]}
-                self.add_port(bridge_name, ovs_port)
+                if ("server" in chardev):
+                    # vhostuserclient
+                    port_name = os.path.basename(chardev["path"])
+                    ovs_port = {"name": port_name,
+                            "type": "dpdkvhostuserclient",
+                            "options:vhost-server-path": chardev["path"]}
+                    self.add_port(bridge_name, ovs_port)
+                else:
+                    # type: vhostuser
+                    port_name = os.path.basename(chardev["path"])
+                    ovs_port = {"name": port_name, "type": "dpdkvhostuser"}
+                    self.add_port(bridge_name, ovs_port)
 
         # 2)start the qemu: tap mode need to start the qemu at frist,
         # vhostuser need to start the ovs-port at first. 
         tmp = self.cmd("%s -daemonize" %(cmd))
+        #self.log("%s -daemonize" %(cmd))
 
         # 3)add the tap port, and add the flow
         for p in vm.get("port", []):
             device = self._util_dictionary_parse(p["-device"].split(","))
             if "vhost-user" in p["-netdev"]:
-                # type: vhostuserclient, add the port before qemu command.
-                print("Have added.")
+                pass
             elif "tap" in p["-netdev"]:
                 # type: tap
                 netdev = self._util_dictionary_parse(p["-netdev"].split(","))
